/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { BucketPermissionIn } from '../models/BucketPermissionIn';
import type { BucketPermissionOut } from '../models/BucketPermissionOut';
import type { BucketPermissionParameters } from '../models/BucketPermissionParameters';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class BucketPermissionsService {

    /**
     * Get permission for bucket and user combination.
     * Get the bucket permissions for the specific combination of bucket and user.
     *
     * The owner of the bucket and the grantee of the permission can view it.
     *
     * @param bucketName Name of bucket
     * @param uid UID of a user
     * @returns BucketPermissionOut Successful Response
     * @throws ApiError
     */
    public static bucketPermissionsGetPermissionForBucket(
        bucketName: string,
        uid: string,
    ): CancelablePromise<BucketPermissionOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/permissions/bucket/{bucket_name}/user/{uid}',
            path: {
                'bucket_name': bucketName,
                'uid': uid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Update a bucket permission
     * Update a permission for a bucket and user.
     *
     * @param uid UID of a user
     * @param bucketName Name of bucket
     * @param requestBody
     * @returns BucketPermissionOut Successful Response
     * @throws ApiError
     */
    public static bucketPermissionsUpdatePermission(
        uid: string,
        bucketName: string,
        requestBody: BucketPermissionParameters,
    ): CancelablePromise<BucketPermissionOut> {
        return __request(OpenAPI, {
            method: 'PUT',
            url: '/permissions/bucket/{bucket_name}/user/{uid}',
            path: {
                'uid': uid,
                'bucket_name': bucketName,
            },
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Delete a bucket permission
     * Delete the bucket permissions for the specific combination of bucket and user.
     *
     * The owner of the bucket and the grantee of the permission can delete it.
     *
     * @param bucketName Name of bucket
     * @param uid UID of a user
     * @returns void
     * @throws ApiError
     */
    public static bucketPermissionsDeletePermissionForBucket(
        bucketName: string,
        uid: string,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/permissions/bucket/{bucket_name}/user/{uid}',
            path: {
                'bucket_name': bucketName,
                'uid': uid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get all permissions for a bucket.
     * List all the bucket permissions for the given bucket.
     *
     * @param bucketName Name of bucket
     * @returns BucketPermissionOut Successful Response
     * @throws ApiError
     */
    public static bucketPermissionsListPermissionsPerBucket(
        bucketName: string,
    ): CancelablePromise<Array<BucketPermissionOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/permissions/bucket/{bucket_name}',
            path: {
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get all permissions for a user.
     * List all the bucket permissions for the given user.
     *
     * @param uid UID of a user
     * @returns BucketPermissionOut Successful Response
     * @throws ApiError
     */
    public static bucketPermissionsListPermissionsPerUser(
        uid: string,
    ): CancelablePromise<Array<BucketPermissionOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/permissions/user/{uid}',
            path: {
                'uid': uid,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Create a permission.
     * Create a permission for a bucket and user.
     *
     * @param requestBody
     * @returns BucketPermissionOut Successful Response
     * @throws ApiError
     */
    public static bucketPermissionsCreatePermission(
        requestBody: BucketPermissionIn,
    ): CancelablePromise<BucketPermissionOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/permissions/',
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
